# Objectives — 归档

过时 / 已关闭的目标。文件原文保留（不改写历史）。

## 清单

| # | 标题 | 归档时间 | 原因 |
|---|---|---|---|
| [O1](O1-closed-loop.md) | 0.1 闭环跑通（付费置顶） | 2026-04-23 | 商业模式 M4 已 pivot 到虚拟信封私信（ADR 2026-04-23-drop-exposure-system），KR1.1-KR1.4 工程部分均已完成 |
| [O2](O2-autonomy-validate.md) | 自治单体假设验证 | 2026-04-23 | 原设定"0.1 运行 30 天后启动"未触发；实际 M4 已证自治单体（不依赖其它 CLI）工作正常 |
